svn commit: r13663 - trunk/src/model/src/org/argouml/model

[email protected]
Newsgroups gmane.comp.lang.uml.argouml.cvs
Message-ID <[email protected]>
Author: tfmorris
Date: 2007-10-10 18:14:22-0700
New Revision: 13663

Modified:
   trunk/src/model/src/org/argouml/model/AbstractCommonBehaviorHelperDecorator.java
   trunk/src/model/src/org/argouml/model/CommonBehaviorHelper.java

Log:
Switch setClassifiers parameter type from Vector to Collection to match underlying UML semantics

Modified: trunk/src/model/src/org/argouml/model/AbstractCommonBehaviorHelperDecorator.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src/model/src/org/argouml/model/AbstractCommonBehaviorHelperDecorator.java?view=diff&rev=13663&p1=trunk/src/model/src/org/argouml/model/AbstractCommonBehaviorHelperDecorator.java&p2=trunk/src/model/src/org/argouml/model/AbstractCommonBehaviorHelperDecorator.java&r1=13662&r2=13663
==============================================================================
--- trunk/src/model/src/org/argouml/model/AbstractCommonBehaviorHelperDecorator.java	(original)
+++ trunk/src/model/src/org/argouml/model/AbstractCommonBehaviorHelperDecorator.java	2007-10-10 18:14:22-0700
@@ -113,10 +113,10 @@
         impl.setOperation(handle, operation);
     }
 
-    public void setClassifiers(Object handle, Vector v) {
-        impl.setClassifiers(handle, v);
+    public void setClassifiers(Object handle, Collection classifiers) {
+        impl.setClassifiers(handle, classifiers);
     }
-
+    
     public void setCommunicationLink(Object handle, Object c) {
         impl.setCommunicationLink(handle, c);
     }

Modified: trunk/src/model/src/org/argouml/model/CommonBehaviorHelper.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src/model/src/org/argouml/model/CommonBehaviorHelper.java?view=diff&rev=13663&p1=trunk/src/model/src/org/argouml/model/CommonBehaviorHelper.java&p2=trunk/src/model/src/org/argouml/model/CommonBehaviorHelper.java&r1=13662&r2=13663
==============================================================================
--- trunk/src/model/src/org/argouml/model/CommonBehaviorHelper.java	(original)
+++ trunk/src/model/src/org/argouml/model/CommonBehaviorHelper.java	2007-10-10 18:14:22-0700
@@ -162,13 +162,15 @@
     void setOperation(Object handle, Object operation);
 
     /**
      * Sets the classifiers of some instance.
      *
      * @param handle is the instance
      * @param v is the classifier vector
      */
-    void setClassifiers(Object handle, Vector v);
-
+    void setClassifiers(Object handle, Collection classifiers);
+    
     /**
      * Sets the communicationLink between a link c and a stimulus handle.
      *
@@ -162,13 +162,15 @@
 
     /**
-     * Sets the classifiers of some instance.
-     *
-     * @param handle is the instance
-     * @param v is the classifier vector
+     * Sets the classifiers of the given instance.
+     * 
+     * @param handle
+     *                is the instance
+     * @param classifiers
+     *                collection of classifiers
      */
lmpx.com only provides a reader for public news (NNTP) servers. It is not affiliated with the servers or forums shown here and is not responsible for the content of articles, which is written by their respective authors.